\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{vwa}[2016/10/01 v1.1 VWA Class]

% ================================= Load parent class

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}
\ProcessOptions\relax
\LoadClass[a4paper,12pt]{scrartcl}

% ================================= Package inclusion

\RequirePackage[utf8]{inputenc}
\RequirePackage[TS1,T1]{fontenc}
\RequirePackage[naustrian]{babel}
\RequirePackage{graphicx}

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsthm}
\PassOptionsToPackage{usenames,dvipsnames,svgnames,table}{xcolor}
\RequirePackage{xcolor}
\RequirePackage{setspace}

\RequirePackage{xspace}
\RequirePackage{tikz}
% ================================= Page Setup

  
\PassOptionsToPackage{a4paper,left=25mm,bindingoffset=10mm,right=25mm,top=15mm,bottom=15mm,includeheadfoot}{geometry}
\RequirePackage{geometry}

\RequirePackage{scrlayer-scrpage}
\pagestyle{scrheadings}

\ihead{}
\chead{}
\ohead{}

\ifoot{\@VWAVerfasser{}, \@VWAThemaKurz{}}
\cfoot{}
\ofoot{\thepage}

\RequirePackage{hyperref}
\hypersetup{
    colorlinks=true, linktocpage=true, pdfstartpage=1, pdfstartview=FitV,%
    breaklinks=true, pdfpagemode=UseNone, pageanchor=true, pdfpagemode=UseOutlines,
    plainpages=false, bookmarksnumbered, bookmarksopen=true, bookmarksopenlevel=1,
    hypertexnames=true, pdfhighlight=/O,
    urlcolor=Brown, linkcolor=RoyalBlue, citecolor=Green
}

\addto\extrasngerman{
\renewcommand{\abstractname}{Abstract}%
\renewcommand{\refname}{Literaturverzeichnis}%
\renewcommand{\figureautorefname}{Abbildung}%
\renewcommand{\tableautorefname}{Tabelle}%
\renewcommand{\partautorefname}{Teil}%
\renewcommand{\chapterautorefname}{Kapitel}%
\renewcommand{\sectionautorefname}{Abschnitt}%
\renewcommand{\subsectionautorefname}{Abschnitt}%
\renewcommand{\subsubsectionautorefname}{Abschnitt}% 	
\renewcommand{\paragraphautorefname}{Absatz}%
\renewcommand{\subparagraphautorefname}{Unterabsatz}%
\renewcommand{\footnoteautorefname}{Fußnote}%
\renewcommand{\FancyVerbLineautorefname}{Zeile}%
\providecommand{\theoremautorefname}{Theorem}%
\providecommand{\lemmaautorefname}{Lemma}%
\providecommand{\corollaryautorefname}{Korollar}%
\renewcommand{\appendixautorefname}{Anhang}%
\renewcommand{\equationautorefname}{Gleichung}%        
\renewcommand{\itemautorefname}{Punkt}%
\providecommand{\subfigureautorefname}{\figureautorefname}%
}

% ================================= internal Variable declaration
\newcommand\@VWAHeaderImageTitlePage{\relax}
\newcommand\@VWAThema{}
\newcommand\@VWAThemaKurz{}
\newcommand\@VWAVerfasser{}
\newcommand\@VWAVerfasserAdresse{}
\newcommand\@VWAVerfasserOrt{}
\newcommand\@VWAKlasse{}
\newcommand\@VWASchule{}
\newcommand\@VWASchuleAdresse{}
\newcommand\@VWABetreuungsperson{}
\newcommand\@VWADatum{}

\newcommand\@VWAErklaerung{\relax}

\newcommand\@VWAFontThema{\Large\bfseries}
\newcommand\@VWAFontVerfasser{\large\bfseries}
\newcommand\@VWAFontKlasse{}
\newcommand\@VWAFontSchule{\bfseries}
\newcommand\@VWAFontSchuleAdresse{}
\newcommand\@VWAFontBetreuungsperson{}
\newcommand\@VWAFontDatum{}
\newcommand\@VWAFontCaption{\footnotesize}
\newcommand\@VWAFontFootnote{\footnotesize}
\newcommand\@VWAFontText{\normalfont\raggedright\setstretch{1.5}}
\newcommand\@VWAFontQuote{\normalfont\raggedright\setstretch{1.0}\itshape}
\newcommand\@VWAFontHeadFoot{\normalfont}


% ================================= Hook AtBeginDocument

\AtBeginDocument{

\begin{titlepage}

\thispagestyle{empty}

\if\@VWAHeaderImageTitlePage\relax \else{
\begin{tikzpicture}[remember picture,overlay]
  \node[inner sep=0,outer sep=0,below right] at (current page.north west){\includegraphics[width=\paperwidth]{\@VWAHeaderImageTitlePage}};
\end{tikzpicture}
}
\fi

\begin{center}
\vspace*{2.5cm}
{ \@VWAFontThema \@VWAThema }\par
\vspace{2.5cm}
{ \@VWAFontVerfasser \@VWAVerfasser }\par
{ \@VWAFontKlasse Klasse \@VWAKlasse } \par
\vspace{1.25cm}

{ \@VWAFontSchule \@VWASchule } \par
{ \@VWAFontSchuleAdresse \@VWASchuleAdresse } \par
\vspace{0.625cm}
{ \@VWAFontBetreuungsperson Betreut durch \@VWABetreuungsperson } \par
\vspace{2.5cm}
{ \@VWAFontDatum Eingereicht am \@VWADatum } \par
\end{center}

\end{titlepage}

\@VWAFontText
}

% ================================= Hook AtEndDocument


\AtEndDocument{
\if\@VWAErklaerung\relax \else {
\clearpage
\setstretch{1.0}
\thispagestyle{empty}
\begin{flushright}
\@VWAVerfasser{}\par
\@VWAVerfasserAdresse{}
\end{flushright}
\vspace{3cm}
\section*{Selbstständigkeitserklärung}
Ich erkläre, dass ich diese vorwissenschaftliche Arbeit eigenständig angefertigt und nur die im Literaturverzeichnis angeführten Quellen und Hilfsmittel benutzt habe.\par
\vspace{2cm}
\begin{minipage}[t]{0.45\textwidth}
\@VWAVerfasserOrt{}, am \@VWADatum{}
\end{minipage} \hfill
\begin{minipage}[t]{0.5\textwidth}
\dotfill\par { \hfill \@VWAFontFootnote Unterschrift \@VWAVerfasser{} \hfill }
\end{minipage}
}
\fi
}

% ================================= Environments and Macros

\newcommand\VWAHeaderImageTitlePage[1]{\renewcommand\@VWAHeaderImageTitlePage{#1}}
\newcommand\VWAThema[2][\relax]{\title{#2}\renewcommand\@VWAThema{#2}%
\if#1\relax \renewcommand\@VWAThemaKurz{#2} \else \renewcommand\@VWAThemaKurz{#1} \fi}
\newcommand\VWAVerfasser[1]{\author{#1}\renewcommand\@VWAVerfasser{#1}}
\newcommand\VWAVerfasserAdresse[1]{\renewcommand\@VWAVerfasserAdresse{#1}}
\newcommand\VWAVerfasserOrt[1]{\renewcommand\@VWAVerfasserOrt{#1}}
\newcommand\VWAKlasse[1]{\renewcommand\@VWAKlasse{#1}}
\newcommand\VWASchule[1]{\renewcommand\@VWASchule{#1}}
\newcommand\VWASchuleAdresse[1]{\renewcommand\@VWASchuleAdresse{#1}}
\newcommand\VWABetreuungsperson[1]{\renewcommand\@VWABetreuungsperson{#1}}
\newcommand\VWADatum[1]{\date{#1}\renewcommand\@VWADatum{#1}}

\newcommand\VWAErklaerung{\renewcommand\@VWAErklaerung{JA}}

\newcommand\VWAFont[2]{\expandafter\renewcommand\csname @VWAFont#1\endcsname{#2}}

\renewenvironment{quote}{\list{}{\leftmargin=10mm}\item\relax \@VWAFontQuote}{\endlist}

\renewenvironment{abstract}{\clearpage\section*{Abstract}}{\newpage}
\newenvironment{vorwort}{\clearpage\section*{Vorwort}}{\par\bigskip\@VWAVerfasserOrt{}, am \@VWADatum{}\hfill \@VWAVerfasser{}\newpage}


\setkomafont{disposition}{\bfseries\rmfamily}
\setkomafont{captionlabel}{\@VWAFontCaption}
\setkomafont{caption}{\@VWAFontCaption}
\setkomafont{footnote}{\@VWAFontFootnote}
\setkomafont{pageheadfoot}{\@VWAFontHeadFoot}

